@@ -93,7 +93,7 @@ filter_function (DBusConnection *connection, DBusMessage *message, void *user_da
     		dbus_error_init (&error);
     		if (dbus_message_get_args 
        			(message, &error, DBUS_TYPE_STRING, &s, DBUS_TYPE_INVALID)) {
-      			d(g_print("New Feed received: %s\n", s));
+      			g_print("New Feed received: %s\n", s);
 			feed->feed_url = g_strdup(s);
 			feed->add=1;
 			feed->enabled=feed->validate=1;
@@ -103,6 +103,7 @@ filter_function (DBusConnection *connection, DBusMessage *message, void *user_da
                 		gchar *text = feed->feed_url;
                 		feed->feed_url = sanitize_url(feed->feed_url);
                 		g_free(text);
+      				d(g_print("sanitized feed URL: %s\n", feed->feed_url));
                 		if (g_hash_table_find(rf->hr,
                                         check_if_match,
                         	        feed->feed_url))
@@ -136,11 +137,11 @@ filter_function (DBusConnection *connection, DBusMessage *message, void *user_da
     		return DBUS_HANDLER_RESULT_HANDLED;
   	}
 	else if (dbus_message_is_signal (message, DBUS_INTERFACE, "ping")) {
-		g_print("!!!PING!!!\n");
 		gchar *data = g_strdup("PONG");
 		DBusMessage *reply;
-		fprintf(stderr, "Ping received from %s\n",
-		dbus_message_get_sender(message));
+		fprintf(stderr, "!!Ping!! received from %s\n",
+				dbus_message_get_sender(message));
+		fprintf(stderr, "Sending !!Pong!! back\n");
 		reply = dbus_message_new_signal (DBUS_PATH, DBUS_REPLY_INTERFACE, "pong");
 //		dbus_message_set_reply_serial(reply,
 //			dbus_message_get_serial(message));
