@@ -48,6 +48,12 @@ gchar *
 strextr(gchar *text, gchar *substr)
 {
  	g_return_val_if_fail( text != NULL, NULL);
+ 	if (substr == NULL)
+		return g_strdup(text);
+	//first check if string contains the substring
+	if (!strstr(text, substr))
+		return g_strdup(text);
+
 	char *tmp = g_strdup(text);
 	GString *str = g_string_new(NULL);
 	g_string_append(str, tmp);
@@ -63,15 +69,23 @@ strextr(gchar *text, gchar *substr)
 gchar *
 sanitize_url(gchar *text)
 {
-	if (strstr(text, "feed//"))
-		text = strextr(text, "feed//");
+	gchar *out;
+	gchar *tmptext = g_strdup(text);
 	if (strstr(text, "feed://"))
-		text = strextr(text, "feed://");
- 	if (!strstr (text, "http://") 
-	&& !strstr (text, "https://"))
- 		return g_strconcat("http://", text, NULL);
+		tmptext = strextr(text, "feed://");
+	else if (strstr(text, "feed//"))
+		tmptext = strextr(text, "feed//");
+	else if (strstr(text, "feed:"))
+		tmptext = strextr(text, "feed:");
+
+ 	if (!strstr (tmptext, "http://") 
+	&& !strstr (tmptext, "https://"))
+		out = g_strconcat("http://", tmptext, NULL);
  	else
- 		return g_strdup(text);
+		out = g_strdup(tmptext);
+
+	g_free(tmptext);
+ 	return out;
 }
 
 //evolution folder must not contain certain chars
@@ -112,15 +126,34 @@ get_url_basename(gchar *url)
  	else
  		return url;
 }
+
+gchar *
+get_port_from_uri(gchar *uri)
+{
+ 	g_return_val_if_fail( uri != NULL, NULL);
  
+	if (strstr(uri, "://") == NULL)
+		return NULL;
+ 	gchar **str = g_strsplit(uri, "://", 2);
+        gchar **str2 = g_strsplit(str[1], "/", 2);
+        gchar **str3 = g_strsplit(str2[0], ":", 2);
+        gchar *port = g_strdup(str3[1]);
+ 	g_strfreev(str);
+ 	g_strfreev(str2);
+ 	g_strfreev(str3);
+ 	return port;
+}
+
 gchar *
 get_server_from_uri(gchar *uri)
 {
  	g_return_val_if_fail( uri != NULL, NULL);
  
+	if (strstr(uri, "://") == NULL)
+		return NULL;
  	gchar **str = g_strsplit(uri, "://", 2);
-         gchar **str2 = g_strsplit(str[1], "/", 2);
-         gchar *server = g_strdup_printf("%s://%s", str[0], str2[0]);
+        gchar **str2 = g_strsplit(str[1], "/", 2);
+        gchar *server = g_strdup_printf("%s://%s", str[0], str2[0]);
  	g_strfreev(str);
  	g_strfreev(str2);
  	return server;
