@@ -26,6 +26,10 @@
 
 #include "rss.h"
 
+static guint feed_enabled = 0;
+static guint feed_validate = 0;
+static guint feed_html = 0;
+
 #define RSS_CONTROL_ID  "OAFIID:GNOME_Evolution_RSS:" EVOLUTION_VERSION_STRING
 #define FACTORY_ID      "OAFIID:GNOME_Evolution_RSS_Factory:" EVOLUTION_VERSION_STRING
 
@@ -37,6 +41,8 @@ typedef struct {
         GtkWidget   *check2;
         GtkWidget   *nettimeout;
         GtkWidget   *check3;
+        GtkWidget   *check4;
+        GtkWidget   *check5;
 } UIData;
 
 static void feeds_dialog_edit(GtkDialog *d, gpointer data);
@@ -63,7 +69,7 @@ set_sensitive (GtkCellLayout   *cell_layout,
 #endif
 
   if (indices[0] == 2)
-#ifdef HAVE_GTKMOZEMBED
+#ifdef HAVE_GECKO
         sensitive = 1;
 #else
         sensitive = 0;
@@ -96,7 +102,7 @@ render_engine_changed (GtkComboBox *dropdown, GCallback *user_data)
                 return;
         if (!id) id = 10;
         gconf_client_set_int(rss_gconf, GCONF_KEY_HTML_RENDER, id, NULL);
-#ifdef HAVE_GTKMOZEMBED
+#ifdef HAVE_GECKO
         if (id == 2)
                 rss_mozilla_init();
 #endif
@@ -290,7 +296,7 @@ create_dialog_add(gchar *text, gchar *feed_text)
 
         GtkWidget *dialog1 = (GtkWidget *)glade_xml_get_widget (gui, "feed_dialog");
 	gtk_widget_show(dialog1);
-  	gtk_window_set_keep_above(GTK_WINDOW(dialog1), TRUE);
+  	gtk_window_set_keep_above(GTK_WINDOW(dialog1), FALSE);
  	if (text != NULL)
         	gtk_window_set_title (GTK_WINDOW (dialog1), _("Edit Feed"));
   	else
@@ -422,7 +428,6 @@ create_dialog_add(gchar *text, gchar *feed_text)
                               GTK_ACCEL_VISIBLE);
 	gtk_window_add_accel_group (GTK_WINDOW (dialog1), accel_group);
 
-
   	gint result = gtk_dialog_run(GTK_DIALOG(dialog1));
   	switch (result)
   	{
@@ -798,10 +803,8 @@ remove_feed_dialog(gchar *msg)
   GtkWidget *cancelbutton1;
   GtkWidget *okbutton1;
 
-  dialog1 = gtk_dialog_new ();
+  dialog1 = e_error_new(NULL, "org-gnome-evolution-rss:ask-delete-feed", msg, NULL);
   gtk_window_set_keep_above(GTK_WINDOW(dialog1), TRUE);
-  gtk_window_set_title (GTK_WINDOW (dialog1), _("Delete Feed?"));
-  gtk_window_set_type_hint (GTK_WINDOW (dialog1), GDK_WINDOW_TYPE_HINT_DIALOG);
 
   dialog_vbox1 = GTK_DIALOG (dialog1)->vbox;
   gtk_widget_show (dialog_vbox1);
@@ -811,12 +814,6 @@ remove_feed_dialog(gchar *msg)
   gtk_box_pack_start (GTK_BOX (dialog_vbox1), vbox1, TRUE, TRUE, 0);
   gtk_container_set_border_width (GTK_CONTAINER (vbox1), 10);
 
-  label1 = gtk_label_new (msg);
-  gtk_widget_show (label1);
-  gtk_box_pack_start (GTK_BOX (vbox1), label1, TRUE, TRUE, 0);
-  gtk_label_set_use_markup (GTK_LABEL (label1), TRUE);
-  gtk_label_set_justify (GTK_LABEL (label1), GTK_JUSTIFY_CENTER);
-
   checkbutton1 = gtk_check_button_new_with_mnemonic (_("Remove folder contents"));
   gtk_widget_show (checkbutton1);
   gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (checkbutton1),
@@ -831,16 +828,6 @@ remove_feed_dialog(gchar *msg)
   gtk_widget_show (dialog_action_area1);
   gtk_button_box_set_layout (GTK_BUTTON_BOX (dialog_action_area1), GTK_BUTTONBOX_END);
 
-  okbutton1 = gtk_button_new_from_stock ("gtk-delete");
-  gtk_widget_show (okbutton1);
-  gtk_dialog_add_action_widget (GTK_DIALOG (dialog1), okbutton1, GTK_RESPONSE_OK);
-  GTK_WIDGET_SET_FLAGS (okbutton1, GTK_CAN_DEFAULT);
-
-  cancelbutton1 = gtk_button_new_with_label (_("Do not delete"));
-  gtk_widget_show (cancelbutton1);
-  gtk_dialog_add_action_widget (GTK_DIALOG (dialog1), cancelbutton1, GTK_RESPONSE_CANCEL);
-  GTK_WIDGET_SET_FLAGS (cancelbutton1, GTK_CAN_DEFAULT);
-  GTK_WIDGET_SET_FLAGS (cancelbutton1, GTK_HAS_FOCUS);
   return dialog1;
 }
 
@@ -857,12 +844,10 @@ feeds_dialog_delete(GtkDialog *d, gpointer data)
         {
                 rf->import = 1;
                 gtk_tree_model_get (model, &iter, 1, &name, -1);
-                gchar *msg = g_strdup_printf(_("Are you sure you want\n to remove <b>%s</b>?"), name);
-                GtkWidget *rfd = remove_feed_dialog(msg);
+                GtkWidget *rfd = remove_feed_dialog(name);
                 gtk_widget_show(rfd);
                 g_signal_connect(rfd, "response", G_CALLBACK(delete_response), data);
                 g_signal_connect(rfd, "destroy", G_CALLBACK(destroy_delete), rfd);
-                g_free(msg);
                 g_free(name);
         }
 }
@@ -994,15 +979,69 @@ import_dialog_response(GtkWidget *selector, guint response, gpointer user_data)
                 rf->cancel = 1;
 }
 
-void
-import_opml(gchar *file, add_feed *feed)
+gboolean
+import_one_feed(gchar *url, gchar *title)
 {
-        xmlChar *buff = NULL;
-        //some defaults
+        add_feed *feed = g_new0(add_feed, 1);
         feed->changed=0;
         feed->add=1;
+        feed->fetch_html = feed_html;
+        feed->validate = feed_validate;
+	feed->enabled = feed_enabled;
+	feed->feed_url = g_strdup(url);
+	feed->feed_name = decode_html_entities(title);
+	/* we'll get rid of this as soon as we fetch unblocking */
+        if (g_hash_table_find(rf->hr,
+                                     check_if_match,
+                                     feed->feed_url))
+        {
+               rss_error(NULL, feed->feed_name, _("Error adding feed."),
+                                _("Feed already exists!"));
+               return FALSE;
+        }
+        guint res = setup_feed(feed);
+        d(g_print("feed imported:%d\n", res));
+        g_free(feed->feed_url);
+        g_free(feed->feed_name);
+	g_free(feed);
+	return res;
+}
+
+/*
+ * type 0/1 - opml/foaf
+ */
+
+xmlNode*
+iterate_import_file(xmlNode *src, gchar **url, xmlChar **title, guint type)
+{
+	*url = NULL;
+	*title = NULL;
+
+	if (type == 0) {
+        	src = html_find(src, "outline");
+        	*url = xmlGetProp(src, "xmlUrl");
+		*title = xmlGetProp(src, "title");
+	} else if (type == 1) {
+		xmlNode *my;
+		src = html_find(src, "member");
+		my = layer_find_pos(src, "member", "Agent");
+		*title = xmlCharStrdup(layer_find(my, "name", NULL));
+		my =  html_find(my, "channel");
+		*url =  xmlGetProp(my, "about");
+	}
+	return src;
+	
+}
+
+void
+import_opml(gchar *file)
+{
+	gchar *url = NULL;
+	xmlChar *name = NULL;
+        xmlChar *buff = NULL;
         guint total = 0;
         guint current = 0;
+	guint type = 0; //file type
         gchar *what = NULL;
         GtkWidget *import_dialog;
         GtkWidget *import_label;
@@ -1010,6 +1049,7 @@ import_opml(gchar *file, add_feed *feed)
 
         xmlNode *src = (xmlNode *)xmlParseFile (file);
         xmlNode *doc = src;
+	xmlNode *my = src;
         gchar *msg = g_strdup(_("Importing feeds..."));
         import_dialog = e_error_new((GtkWindow *)rf->preferences, "shell:importing", msg, NULL);
         gtk_window_set_keep_above(GTK_WINDOW(import_dialog), TRUE);
@@ -1028,63 +1068,80 @@ import_opml(gchar *file, add_feed *feed)
                 0);
         gtk_widget_show_all(import_dialog);
         g_free(msg);
-        xmlNode *wlk = src;
-	while (wlk->next)
+	if (src=src->children)
 	{
-		g_print("juj:%s\n", layer_find_innerelement(wlk, "Group", "name", NULL));
-	printf ("%p, %s\n", wlk, wlk->name);	
-		wlk = wlk->next;
-	}
-        while (src = html_find(src, "outline"))
-        {
-                feed->feed_url = xmlGetProp((xmlNode *)src, "xmlUrl");
-                if (feed->feed_url)
-                {
-                        total++;
-                        xmlFree(feed->feed_url);
-                }
-        }
+		d(g_print("found %s\n", src->name));
+		if (!g_ascii_strcasecmp(src->name, "rdf")) {
+			while (src) {
+				g_print("my cont:%s\n", src->content);
+				src=src->children;
+				src = src->next;
+				g_print("found %s\n", src->name);
+				src = src->children;
+				d(g_print("group name:%s\n", layer_find(src, "name", NULL)));
+				src = src->next;
+				while (src = iterate_import_file(src, &url, &name, 1)) {
+                			if (url) {
+                        			total++;
+                        			xmlFree(url);
+                			}
+					if (name) xmlFree(name);
+				}
+			g_print("total:%d\n", total);
+			type = 1;
+			}
+		}
+		else if (!g_ascii_strcasecmp(src->name, "opml")) {
+			
+			while (src = iterate_import_file(src, &url, &name, 0)) {
+                		if (url && strlen(url)) {
+                        		total++;
+                        		xmlFree(url);
+                		}
+				if (name) xmlFree(name);
+        		}
+			type = 0;
+			g_print("total:%d\n", total);
+		}
+	}	
         src = doc;
+//	//force out for now
+//	goto out;
         //we'll be safer this way
         rf->import = 1;
+	name = NULL;
         while (gtk_events_pending ())
                 gtk_main_iteration ();
-        while (src = html_find(src, "outline"))
-        {
-                feed->feed_url = xmlGetProp((xmlNode *)src, "xmlUrl");
-                if (feed->feed_url && strlen(feed->feed_url))
-                {
+	if (type == 1) {
+		src=src->children;
+		g_print("my cont:%s\n", src->content);
+		src=src->children;
+		src = src->next;
+		g_print("found %s\n", src->name);
+		src = src->children;
+		d(g_print("group name:%s\n", layer_find(src, "name", NULL)));
+		src = src->next;
+	}
+	while (src = iterate_import_file(src, &url, &name, type)) {
+                if (url && strlen(url)) {
+		g_print("url:%s\n", url);
                         if (rf->cancel)
                         {
                                 if (src) xmlFree(src);
                                 rf->cancel = 0;
                                 goto out;
                         }
-                        gchar *name = xmlGetProp((xmlNode *)src, "title");
-                        gchar *safe_name = decode_html_entities(name);
-                        xmlFree(name);
-                        name = safe_name;
-
                         gtk_label_set_text(GTK_LABEL(import_label), name);
-#if GTK_2_6
+#if GTK_VERSION >= 2006000
                         gtk_label_set_ellipsize (GTK_LABEL (import_label), PANGO_ELLIPSIZE_START);
 #endif
                         gtk_label_set_justify(GTK_LABEL(import_label), GTK_JUSTIFY_CENTER);
-                        feed->feed_name = name;
-                        /* we'll get rid of this as soon as we fetch unblocking */
-                        if (g_hash_table_find(rf->hr,
-                                        check_if_match,
-                                        feed->feed_url))
-                        {
-                           rss_error(NULL, feed->feed_name, _("Error adding feed."),
-                                           _("Feed already exists!"));
-                           continue;
-                        }
-                        guint res = setup_feed(feed);
+			import_one_feed(url, name);
+			if (name) xmlFree(name);
+			if (url) xmlFree(url);
 
                         while (gtk_events_pending ())
                                 gtk_main_iteration ();
-                        d(g_print("feed imported:%d\n", res));
                         current++;
                         float fr = ((current*100)/total);
                         gtk_progress_bar_set_fraction((GtkProgressBar *)import_progress, fr/100);
@@ -1097,7 +1154,6 @@ import_opml(gchar *file, add_feed *feed)
                         gtk_list_store_clear(GTK_LIST_STORE(model));
                         g_hash_table_foreach(rf->hrname, construct_list, model);
                         save_gconf_feed();
-                        g_free(feed->feed_url);
                         if (src)
                                 xmlFree(src);
                 }
@@ -1110,8 +1166,6 @@ import_opml(gchar *file, add_feed *feed)
 out:    rf->import = 0;
         xmlFree(doc);
         gtk_widget_destroy(import_dialog);
-//how the hell should I free this ?
-////      g_free(feed);
 }
 
 static void
@@ -1122,7 +1176,7 @@ select_file_response(GtkWidget *selector, guint response, gpointer user_data)
                 if (name)
                 {
                         gtk_widget_hide(selector);
-                        import_opml(name, user_data);
+                        import_opml(name);
                         g_free(name);
                 }
         }
@@ -1131,27 +1185,26 @@ select_file_response(GtkWidget *selector, guint response, gpointer user_data)
 }
 
 static void
-import_toggle_cb_html (GtkWidget *widget, add_feed *data)
+import_toggle_cb_html (GtkWidget *widget, gpointer data)
 {
-        data->fetch_html  = 1-gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (widget));
+        feed_html  = 1-gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (widget));
 }
 
 static void
-import_toggle_cb_valid (GtkWidget *widget, add_feed *data)
+import_toggle_cb_valid (GtkWidget *widget, gpointer data)
 {
-        data->validate  = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (widget));
+        feed_validate  = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (widget));
 }
 
 static void
-import_toggle_cb_ena (GtkWidget *widget, add_feed *data)
+import_toggle_cb_ena (GtkWidget *widget, gpointer data)
 {
-        data->enabled  = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (widget));
+        feed_enabled  = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (widget));
 }
 
 static void
 decorate_import_fs (gpointer data)
 {
-        add_feed *feed = g_new0(add_feed, 1);
         gtk_file_chooser_set_do_overwrite_confirmation (GTK_FILE_CHOOSER (data), TRUE);
         gtk_dialog_set_default_response (GTK_DIALOG (data), GTK_RESPONSE_OK);
         gtk_file_chooser_set_local_only (data, FALSE);
@@ -1209,22 +1262,22 @@ decorate_import_fs (gpointer data)
         gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (checkbutton3), 1);
 
         gtk_file_chooser_set_extra_widget(data, vbox1);
-        feed->fetch_html = 0;
-        feed->validate = feed->enabled = 1;
+        feed_html = 0;
+        feed_validate = feed_enabled = 1;
 
         g_signal_connect(checkbutton1,
                         "toggled",
                         G_CALLBACK(import_toggle_cb_html),
-                        feed);
+                        NULL);
         g_signal_connect(checkbutton2,
                         "toggled",
                         G_CALLBACK(import_toggle_cb_ena),
-                        feed);
+                        NULL);
         g_signal_connect(checkbutton3,
                         "toggled",
                         G_CALLBACK(import_toggle_cb_valid),
-                        feed);
-        g_signal_connect(data, "response", G_CALLBACK(select_file_response), feed);
+                        NULL);
+        g_signal_connect(data, "response", G_CALLBACK(select_file_response), NULL);
         g_signal_connect(data, "destroy", G_CALLBACK(gtk_widget_destroy), data);
 }
 
@@ -1530,7 +1583,7 @@ e_plugin_lib_get_configure_widget (EPlugin *epl)
         gladefile = g_build_filename (EVOLUTION_GLADEDIR,
                         "rss-html-rendering.glade",
                         NULL);
-        ui->xml = glade_xml_new (gladefile, "html-rendering", NULL);
+        ui->xml = glade_xml_new (gladefile, "settingsbox", NULL);
         g_free (gladefile);
 
 
@@ -1561,7 +1614,7 @@ e_plugin_lib_get_configure_widget (EPlugin *epl)
                         break;
 #endif
                 case 2:
-#ifndef HAVE_GTKMOZEMBED
+#ifndef HAVE_GECKO
                         gtk_combo_box_set_active(GTK_COMBO_BOX(combo), 0);
                         break;
 #endif
@@ -1576,7 +1629,7 @@ e_plugin_lib_get_configure_widget (EPlugin *epl)
                                         set_sensitive,
                                         NULL, NULL);
 
-#if !defined(HAVE_GTKMOZEMBED) && !defined (HAVE_WEBKIT)
+#if !defined(HAVE_GECKO) && !defined (HAVE_WEBKIT)
         GtkWidget *label_webkit = glade_xml_get_widget(ui->xml, "label_webkits");
         gtk_label_set_text(GTK_LABEL(label_webkit), _("Note: In order to be able to use Mozilla (Firefox) or Apple Webkit \nas renders you need firefox or webkit devel package \ninstalled and evolution-rss should be recompiled to see those packages."));
         gtk_widget_show(label_webkit);
@@ -1608,10 +1661,35 @@ e_plugin_lib_get_configure_widget (EPlugin *epl)
 	g_signal_connect(ui->nettimeout, "changed", G_CALLBACK(network_timeout_cb), ui->nettimeout);
 	g_signal_connect(ui->nettimeout, "value-changed", G_CALLBACK(network_timeout_cb), ui->nettimeout);
 
+	//feed notification
+	
+	ui->check3 = glade_xml_get_widget(ui->xml, "status_icon");
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (ui->check3),
+        	gconf_client_get_bool(rss_gconf, GCONF_KEY_STATUS_ICON, NULL));
+	g_signal_connect(ui->check3, 
+		"clicked", 
+		G_CALLBACK(start_check_cb), 
+		GCONF_KEY_STATUS_ICON);
+	ui->check4 = glade_xml_get_widget(ui->xml, "blink_icon");
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (ui->check4),
+        	gconf_client_get_bool(rss_gconf, GCONF_KEY_BLINK_ICON, NULL));
+	g_signal_connect(ui->check4, 
+		"clicked", 
+		G_CALLBACK(start_check_cb), 
+		GCONF_KEY_BLINK_ICON);
+	ui->check5 = glade_xml_get_widget(ui->xml, "feed_icon");
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (ui->check5),
+        	gconf_client_get_bool(rss_gconf, GCONF_KEY_FEED_ICON, NULL));
+	g_signal_connect(ui->check5, 
+		"clicked", 
+		G_CALLBACK(start_check_cb), 
+		GCONF_KEY_FEED_ICON);
+	
+
         ui->gconf = gconf_client_get_default ();
 	hbox = gtk_vbox_new (FALSE, 0);
 
-        gtk_box_pack_start (GTK_BOX (hbox), glade_xml_get_widget (ui->xml, "html-rendering"), FALSE, FALSE, 0);
+        gtk_box_pack_start (GTK_BOX (hbox), glade_xml_get_widget (ui->xml, "settingsbox"), FALSE, FALSE, 0);
 
 	g_object_set_data_full (G_OBJECT (hbox), "ui-data", ui, destroy_ui_data);
 
@@ -1658,7 +1736,7 @@ folder_factory (EPlugin *epl, EConfigHookItemFactoryData *data)
         gtk_widget_show (lbl_size_val);
         gtk_misc_set_alignment (GTK_MISC (lbl_size), 0.0, 0.5);
         gtk_misc_set_alignment (GTK_MISC (lbl_size_val), 0.0, 0.5);
-       gtk_box_pack_start (GTK_BOX (dialog1), lbl_size, FALSE, TRUE, 12);
+        gtk_box_pack_start (GTK_BOX (dialog1), lbl_size, FALSE, TRUE, 12);
         gtk_box_pack_start (GTK_BOX (dialog1), lbl_size_val, FALSE, TRUE, 10);
         gtk_widget_show_all (GTK_WIDGET (dialog1));
 
@@ -1719,7 +1797,7 @@ rss_config_control_new (void)
                                column);
 	cell = gtk_cell_renderer_text_new ();
 	g_object_set (cell,
-                "ellipsize", PANGO_ELLIPSIZE_MIDDLE,
+                "ellipsize", PANGO_ELLIPSIZE_END,
                 NULL);
 	g_object_set (cell,
                 "is-expanded", TRUE,
@@ -1747,7 +1825,10 @@ rss_config_control_new (void)
 	gtk_tree_view_column_set_sort_column_id (column, 2);
 	gtk_tree_view_set_search_column (GTK_TREE_VIEW (treeview),
                                                    2);
+	gtk_tree_view_set_search_column(treeview, 1);
+#if GTK_VERSION >= 2012000
 	gtk_tree_view_set_tooltip_column (treeview, 1);
+#endif
 
 	if (rf->hr != NULL)
         	g_hash_table_foreach(rf->hrname, construct_list, store);
@@ -1840,7 +1921,7 @@ rss_config_control_new (void)
 			break;
 #endif
 		case 2:
-#ifndef HAVE_GTKMOZEMBED
+#ifndef HAVE_GECKO
 			gtk_combo_box_set_active(GTK_COMBO_BOX(combo), 0);
 			break;
 #endif
@@ -1855,7 +1936,7 @@ rss_config_control_new (void)
 					set_sensitive,
 					NULL, NULL);
 
-#if !defined(HAVE_GTKMOZEMBED) && !defined (HAVE_WEBKIT)
+#if !defined(HAVE_GECKO) && !defined (HAVE_WEBKIT)
 	GtkWidget *label_webkit = glade_xml_get_widget(sf->gui, "label_webkits");
 	gtk_label_set_text(GTK_LABEL(label_webkit), _("Note: In order to be able to use Mozilla (Firefox) or Apple Webkit \nas renders you need firefox or webkit devel package \ninstalled and evolution-rss should be recompiled to see those packages."));
 	gtk_widget_show(label_webkit);
